# Autogenerated by nbdev

d = { 'settings': { 'branch': 'main',
                'doc_baseurl': '/dreamai_pdf',
                'doc_host': 'https://HamzaFarhan.github.io',
                'git_url': 'https://github.com/HamzaFarhan/dreamai_pdf',
                'lib_path': 'dreamai_pdf'},
  'syms': { 'dreamai_pdf.core': { 'dreamai_pdf.core.cid_to_char': ('core.html#cid_to_char', 'dreamai_pdf/core.py'),
                                  'dreamai_pdf.core.color_fill_pdf_text': ('core.html#color_fill_pdf_text', 'dreamai_pdf/core.py'),
                                  'dreamai_pdf.core.combine_lines': ('core.html#combine_lines', 'dreamai_pdf/core.py'),
                                  'dreamai_pdf.core.combine_splits': ('core.html#combine_splits', 'dreamai_pdf/core.py'),
                                  'dreamai_pdf.core.get_avg_gap': ('core.html#get_avg_gap', 'dreamai_pdf/core.py'),
                                  'dreamai_pdf.core.get_max_gap': ('core.html#get_max_gap', 'dreamai_pdf/core.py'),
                                  'dreamai_pdf.core.load_pdf': ('core.html#load_pdf', 'dreamai_pdf/core.py'),
                                  'dreamai_pdf.core.only_bnw': ('core.html#only_bnw', 'dreamai_pdf/core.py'),
                                  'dreamai_pdf.core.pdf_img_to_np': ('core.html#pdf_img_to_np', 'dreamai_pdf/core.py'),
                                  'dreamai_pdf.core.process_text': ('core.html#process_text', 'dreamai_pdf/core.py'),
                                  'dreamai_pdf.core.split_words': ('core.html#split_words', 'dreamai_pdf/core.py')},
            'dreamai_pdf.imports': {},
            'dreamai_pdf.parse': { 'dreamai_pdf.parse.AdaptiveConcatPool2d': ('parse.html#adaptiveconcatpool2d', 'dreamai_pdf/parse.py'),
                                   'dreamai_pdf.parse.AdaptiveConcatPool2d.__init__': ( 'parse.html#adaptiveconcatpool2d.__init__',
                                                                                        'dreamai_pdf/parse.py'),
                                   'dreamai_pdf.parse.AdaptiveConcatPool2d.forward': ( 'parse.html#adaptiveconcatpool2d.forward',
                                                                                       'dreamai_pdf/parse.py'),
                                   'dreamai_pdf.parse.ColumnCounter': ('parse.html#columncounter', 'dreamai_pdf/parse.py'),
                                   'dreamai_pdf.parse.ColumnCounter.draw': ('parse.html#columncounter.draw', 'dreamai_pdf/parse.py'),
                                   'dreamai_pdf.parse.Flatten': ('parse.html#flatten', 'dreamai_pdf/parse.py'),
                                   'dreamai_pdf.parse.Flatten.forward': ('parse.html#flatten.forward', 'dreamai_pdf/parse.py'),
                                   'dreamai_pdf.parse.HeadModel': ('parse.html#headmodel', 'dreamai_pdf/parse.py'),
                                   'dreamai_pdf.parse.HeadModel.__init__': ('parse.html#headmodel.__init__', 'dreamai_pdf/parse.py'),
                                   'dreamai_pdf.parse.HeadModel.forward': ('parse.html#headmodel.forward', 'dreamai_pdf/parse.py'),
                                   'dreamai_pdf.parse.LinBnDrop': ('parse.html#linbndrop', 'dreamai_pdf/parse.py'),
                                   'dreamai_pdf.parse.LinBnDrop.__init__': ('parse.html#linbndrop.__init__', 'dreamai_pdf/parse.py'),
                                   'dreamai_pdf.parse.col_clusters': ('parse.html#col_clusters', 'dreamai_pdf/parse.py'),
                                   'dreamai_pdf.parse.create_head': ('parse.html#create_head', 'dreamai_pdf/parse.py'),
                                   'dreamai_pdf.parse.create_model': ('parse.html#create_model', 'dreamai_pdf/parse.py'),
                                   'dreamai_pdf.parse.get_n_cols': ('parse.html#get_n_cols', 'dreamai_pdf/parse.py'),
                                   'dreamai_pdf.parse.load_cols_model': ('parse.html#load_cols_model', 'dreamai_pdf/parse.py'),
                                   'dreamai_pdf.parse.pdf_cols_to_text': ('parse.html#pdf_cols_to_text', 'dreamai_pdf/parse.py'),
                                   'dreamai_pdf.parse.pdf_to_batch': ('parse.html#pdf_to_batch', 'dreamai_pdf/parse.py'),
                                   'dreamai_pdf.parse.pdf_to_cols': ('parse.html#pdf_to_cols', 'dreamai_pdf/parse.py'),
                                   'dreamai_pdf.parse.pdf_to_text': ('parse.html#pdf_to_text', 'dreamai_pdf/parse.py'),
                                   'dreamai_pdf.parse.pred_cols': ('parse.html#pred_cols', 'dreamai_pdf/parse.py')},
            'dreamai_pdf.segment': { 'dreamai_pdf.segment.get_contact_dict': ('segment.html#get_contact_dict', 'dreamai_pdf/segment.py'),
                                     'dreamai_pdf.segment.get_edu_dicts': ('segment.html#get_edu_dicts', 'dreamai_pdf/segment.py'),
                                     'dreamai_pdf.segment.get_job_dicts': ('segment.html#get_job_dicts', 'dreamai_pdf/segment.py'),
                                     'dreamai_pdf.segment.load_ner_model': ('segment.html#load_ner_model', 'dreamai_pdf/segment.py'),
                                     'dreamai_pdf.segment.load_segs_model': ('segment.html#load_segs_model', 'dreamai_pdf/segment.py'),
                                     'dreamai_pdf.segment.ners_to_dicts': ('segment.html#ners_to_dicts', 'dreamai_pdf/segment.py'),
                                     'dreamai_pdf.segment.segment_to_ners': ('segment.html#segment_to_ners', 'dreamai_pdf/segment.py'),
                                     'dreamai_pdf.segment.text_to_segments': ('segment.html#text_to_segments', 'dreamai_pdf/segment.py')}}}
